Remote Procedure Call Support for Automate
==========================================

Read the documentation at
`Readthedocs.org <http://python-automate.readthedocs.org/en/latest/official_extensions/rpc.html>`_

Installation
------------

Install from Pypi::

    pip install automate-rpc

Optionally, you could install also by cloning GIT repository and installing manually::

    git clone https://github.com/tuomas2/automate-rpc.git
    cd automate-rpc
    ./setup.py install

Licence
-------

Automate is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Automate is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Automate.  If not, see <http://www.gnu.org/licenses/>.